==> plugin.video.orange.fr-2.1.3.zip: plugin.video.orange.fr/README.md <==
# Orange TV France for Kodi
[![GitHub release (latest SemVer)](https://img.shields.io/github/v/release/f-lawe/plugin.video.orange.fr)](https://github.com/f-lawe/plugin.video.orange.fr/releases)
[![Kodi version](https://img.shields.io/badge/kodi%20version-v21-blue)](https://kodi.tv/)
[![GitHub](https://img.shields.io/github/license/f-lawe/plugin.video.orange.fr)](https://github.com/f-lawe/plugin.video.orange.fr/blob/master/LICENSE)

__→__ _[Lisez-moi](doc/README.fr.md) en français_

_This addon is not officially commissioned/supported by Orange. All product names, logos, and trademarks mentionned in this project are property of their respective owners._

## Description
This addon brings Orange TV to Kodi. All channels included in your registration are now directly available from Kodi!

This addon features:
- Watching TV with Kodi TV (using [IPTV Simple PVR](https://github.com/kodi-pvr/pvr.iptvsimple))
- Watching catchup TV content
- Access to paid channels included into your subscription (for both live and catchup TV)

## Installation
Orange TV France is available directly from Kodi's main repository. Integration is handled via [IPTV Manager](https://github.com/add-ons/service.iptv.manager). You can install and activate it from the addon settings. Once set up on your system, channels and TV guide are loaded automatically.

You should now be able to view all the channels grouped by category in the TV section. If not already installed, Kodi will ask you to install the decrypting tool when accessing a channel for the first time.

Do not forget to properly configure IPTV Manager and select your TV provider in the settings!

If you need the latest update, you can download the latest ZIP archive from the [releases page](https://github.com/f-lawe/plugin.video.orange.fr/releases/latest) and manually install it into Kodi (Settings > Addons > Install from ZIP). Then install the dependencies from the addon screen (My addons > Video addons > Orange TV France > Dependencies).

## Available providers
| Country   | Provider          |  |
|:---------:|:------------------|:-|
| 🇫🇷        | Orange            |  |
| 🇫🇷        | Orange Caraïbe    |  |
| 🇫🇷        | Orange Réunion    | thanks to [@starmate](https://github.com/starmate) and [@sae-gfc](https://github.com/sae-gfc) |

## Known limitations
- Limited to 720p because Orange don't provide higher quality on their web TV
- Work only from the listed and tested areas (for now metropolitan France, French Caribbean, and Reunion island)

==> plugin.video.orange.fr-2.2.0.zip: plugin.video.orange.fr/README.md <==
# Orange TV France for Kodi
[![GitHub release (latest SemVer)](https://img.shields.io/github/v/release/f-lawe/plugin.video.orange.fr)](https://github.com/f-lawe/plugin.video.orange.fr/releases)
[![Kodi version](https://img.shields.io/badge/kodi%20version-v21-blue)](https://kodi.tv/)
[![GitHub](https://img.shields.io/github/license/f-lawe/plugin.video.orange.fr)](https://github.com/f-lawe/plugin.video.orange.fr/blob/master/LICENSE)

__→__ _[Lisez-moi](doc/README.fr.md) en français_

_This addon is not officially commissioned/supported by Orange. All product names, logos, and trademarks mentionned in this project are property of their respective owners._

## Description
This addon brings Orange TV to Kodi. All channels included in your registration are now directly available from Kodi!

This addon features:
- Watching TV with Kodi TV (using [IPTV Simple PVR](https://github.com/kodi-pvr/pvr.iptvsimple))
- Watching catchup TV content
- Access to paid channels included into your subscription (for both live and catchup TV)

## Installation
Orange TV France is available directly from Kodi's main repository. Integration is handled via [IPTV Manager](https://github.com/add-ons/service.iptv.manager). You can install and activate it from the addon settings. Once set up on your system, channels and TV guide are loaded automatically.

You should now be able to view all the channels grouped by category in the TV section. If not already installed, Kodi will ask you to install the decrypting tool when accessing a channel for the first time.

Do not forget to properly configure IPTV Manager and select your TV provider in the settings!

If you need the latest update, you can download the latest ZIP archive from the [releases page](https://github.com/f-lawe/plugin.video.orange.fr/releases/latest) and manually install it into Kodi (Settings > Addons > Install from ZIP). Then install the dependencies from the addon screen (My addons > Video addons > Orange TV France > Dependencies).

## Available providers
| Country   | Provider          |  |
|:---------:|:------------------|:-|
| 🇫🇷        | Orange            |  |
| 🇫🇷        | Orange Caraïbe    |  |
| 🇫🇷        | Orange Réunion    | thanks to [@starmate](https://github.com/starmate) and [@sae-gfc](https://github.com/sae-gfc) |

## Known limitations
- Limited to 720p because Orange don't provide higher quality on their web TV
- Work only from the listed and tested areas (for now metropolitan France, French Caribbean, and Reunion island)

## Sponsorship
You like this project? Help me working on it!

[![Donate with PayPal](https://www.paypalobjects.com/en_US/i/btn/btn_donate_LG.gif)](https://www.paypal.com/donate/?hosted_button_id=PNVV6FEQU94JG)
